@@ -4,12 +4,14 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: ftwx.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: ftwx.c,v 1.6 1995/09/10 18:32:56 chuck Exp $" ;
 
+#include <unistd.h>
+
+#include <sys/param.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/file.h>
-#include <stdio.h>
 #ifndef OLD_DIR
 #include <dirent.h>
 #else
@@ -26,8 +28,9 @@ extern int errno ;
 
 #define NUL					'\0'
 
-PRIVATE int ftwx_traverse(char *, int);
-
+#if defined(linux) || defined(BSD)
+PRIVATE int ftwx_traverse( char *path , int depth ) ;
+#endif
 
 typedef enum { NO, YES } boolean_e ;
 
@@ -89,7 +92,9 @@ int ftwx( path, func, depth, flags )
  * Phase 2: if the current path is a directory, it invokes ftwx_traverse
  *				for each directory entry
  */
-PRIVATE int ftwx_traverse(char *path, int depth )
+PRIVATE int ftwx_traverse( path, depth )
+	char *path ;
+	int depth ;
 {
 	DIR *dirp ;
 	struct stat st ;
