@@ -9,10 +9,10 @@
 #define __FTWX_H
 
 /*
- * $Id: ftwx.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: ftwx.h,v 2.1 1992/10/01 00:41:02 panos Exp $
  */
 
-#ifdef HAVE_FTW_H
+#ifndef __FTWX_NO_FTW
 #include <ftw.h>
 #else
 #define FTW_F   0
