@@ -4,13 +4,12 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: misc.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: misc.c,v 1.6 1995/09/10 18:32:56 chuck Exp $" ;
 static char misc_version[] = VERSION ;
 
-#include <varargs.h>
-
 #include <stdlib.h>
-#include <string.h>
+#include <varargs.h>
+#include <sys/param.h>
 
 /*
  * MISCELLANEOUS FUNCTIONS
@@ -22,6 +21,10 @@ static char misc_version[] = VERSION ;
 #define NULL		0
 #endif
 
+char *strncpy() ;
+char *strrchr() ;
+
+
 /*
  * Create a new argv array,
  * copy the original to the new one,
@@ -61,7 +64,6 @@ char **argv_copy_and_clear( org_argv, start, count )
 /*
  * We always return a pointer in pathname
  */
-#if !defined(linux)
 char *basename( pathname )
 	char *pathname ;
 {
@@ -72,7 +74,6 @@ char *basename( pathname )
 	else
 		return( s+1 ) ;
 }
-#endif
 
 
 /*
@@ -101,7 +102,7 @@ char *dirname( pathname )
 			return( make_string( 1, "/" ) ) ;
 	}
 
-	p = (char *)malloc( len+1 ) ;
+	p = malloc( len+1 ) ;
 	if ( p == NULL )
 		return( NULL ) ;
 	else
@@ -135,7 +136,7 @@ char *make_string( count, va_alist )
 	}
 	va_end( ap ) ;
 
-	new_string = (char *)malloc( len + 1 ) ;
+	new_string = malloc( len + 1 ) ;
 	if ( new_string == NULL )
 		return( NULL ) ;
 
@@ -175,7 +176,7 @@ char *make_pathname( count, va_alist )
 	}
 	va_end( ap ) ;
 
-	pathname = (char *)malloc( len + count ) ;
+	pathname = malloc( len + count ) ;
 	if ( pathname == NULL )
 		return( NULL ) ;
 	
