@@ -4,12 +4,12 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: siosup.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: siosup.c,v 1.5 1995/09/10 18:35:09 chuck Exp $" ;
 
 #include <sys/types.h>
+#include <sys/param.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <stdlib.h>
 
 #include "impl.h"
 #include "sio.h"
@@ -18,37 +18,40 @@ static char RCSid[] = "$Id: siosup.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $"
 #include "events.h"
 #endif
 
+#if defined(BSD) || defined(linux)
+PRIVATE void terminate() ;
+PRIVATE status_e setup_read_buffer( register __sio_id_t *idp ,
+        unsigned buf_size );
+#endif
+char *malloc() ;
+char *realloc() ;
+
+
 static __sio_descriptor_t static_descriptor_array[ N_SIO_DESCRIPTORS ] ;
 static int n_descriptors = N_SIO_DESCRIPTORS ;
 __sio_descriptor_t *__sio_descriptors = static_descriptor_array ;
 
-PRIVATE void terminate(char *s);
-PRIVATE status_e setup_read_buffer( register __sio_id_t *idp, unsigned buf_size );
-
 #ifdef EVENTS
 static events_s static___sio_events[ N_SIO_DESCRIPTORS ] ;
 events_s *__sio_events = static___sio_events ;
 #endif
 
-#ifndef MAP_FAILED
-#define MAP_FAILED ((void *)-1)
-#endif
 
 /*
  * Code for finalization
  */
-#ifdef HAVE_FINALIZATION_FUNCTION
+#ifdef HAS_FINALIZATION_FUNCTION
 static int finalizer_installed ;
 
 SIO_DEFINE_FIN( sio_cleanup )
 {
    (void) Sflush( SIO_FLUSH_ALL ) ;
 }
-#endif /* HAVE_FINALIZATION_FUNCTION */
+#endif /* HAS_FINALIZATION_FUNCTION */
 
 
 
-#ifdef HAVE_MMAP
+#ifdef HAS_MMAP
 
 #define CHAR_NULL				((char *)0)
 
@@ -110,7 +113,7 @@ static mapd_s *mmap_descriptors = static_mapd_array ;
  * try_memory_mapping attempts to setup the specified descriptor
  * for memory mapping. 
  * It returns FAILURE if it fails and SUCCESS if it is successful.
- * If HAVE_MMAP is not defined, the function is defined to be FAILURE.
+ * If HAS_MMAP is not defined, the function is defined to be FAILURE.
  *
  * Sets fields:
  *		memory_mapped:			 TRUE or FALSE
@@ -297,7 +300,7 @@ PRIVATE int initial_map( mdp, fd )
 #endif
 
 	addr = SIO_MMAP( CHAR_NULL, mapped_length, fd, 0 ) ;
-	if ( addr == MAP_FAILED )
+	if ( (int) addr == -1 )
 		return( 0 ) ;
 
 	SIO_MNEED( addr, mapped_length ) ;
@@ -355,8 +358,8 @@ PRIVATE status_e map_unit( mdp, fd, mup )
 
 	if ( bytes_to_map > 0 )
 	{
-		if ( SIO_MMAP( mup->addr, bytes_to_map,
-															fd, mdp->file_offset ) == MAP_FAILED )
+		if ( (int) SIO_MMAP( mup->addr, bytes_to_map,
+															fd, mdp->file_offset ) == -1 )
 			return( FAILURE ) ;			/* XXX: need to do more ? */
 		
 		mup->valid_bytes = bytes_to_map ;
@@ -376,7 +379,7 @@ PRIVATE status_e map_unit( mdp, fd, mup )
 
 #define try_memory_mapping( x, y, z )				FAILURE
 
-#endif /* HAVE_MMAP */
+#endif /* HAS_MMAP */
 
 
 PRIVATE status_e setup_read_buffer( idp, buf_size )
@@ -475,9 +478,9 @@ PRIVATE status_e init_output_stream( odp, fd, stp )
 }
 
 
-#ifndef HAVE_ISATTY
+#ifndef HAS_ISATTY
 
-#ifdef HAVE_SYSVTTY
+#ifdef HAS_SYSVTTY
 
 #include <termio.h>
 
@@ -491,9 +494,9 @@ PRIVATE int isatty( fd )
 	else
 		return( TRUE ) ;
 }
-#endif	/* HAVE_SYSVTTY */
+#endif	/* HAS_SYSVTTY */
 
-#ifdef HAVE_BSDTTY
+#ifdef HAS_BSDTTY
 
 #include <sgtty.h>
 
@@ -507,9 +510,9 @@ PRIVATE int isatty( fd )
 	else
 		return( TRUE ) ;
 }
-#endif	/* HAVE_BSDTTY */
+#endif	/* HAS_BSDTTY */
 
-#endif	/* ! HAVE_ISATTY */
+#endif	/* ! HAS_ISATTY */
 
 
 /*
@@ -531,7 +534,9 @@ int __sio_init( dp, fd, stream_type )
 	enum __sio_stream stream_type ;
 {
 	struct stat st ;
+#if !defined(linux) && !defined(BSD)
 	void terminate() ;
+#endif
 
 #ifdef EVENTS
 	EVENT( fd, EV_SIO_INIT ) ;
@@ -559,7 +564,7 @@ int __sio_init( dp, fd, stream_type )
 	dp->stream_type = stream_type ;
 	dp->initialized = TRUE ;
 
-#ifdef HAVE_FINALIZATION_FUNCTION
+#ifdef HAS_FINALIZATION_FUNCTION
 	if ( ! finalizer_installed )
 	{
 		if ( ! SIO_FINALIZE( sio_cleanup ) )
@@ -571,7 +576,7 @@ int __sio_init( dp, fd, stream_type )
 		else
 			finalizer_installed = TRUE ;
 	}
-#endif /* HAVE_FINALIZATION_FUNCTION */
+#endif /* HAS_FINALIZATION_FUNCTION */
 
 	return( 0 ) ;
 }
@@ -680,7 +685,7 @@ int __sio_readf( idp, fd )
 	if ( idp->tied_fd != SIO_NO_TIED_FD )
 		(void) __sio_writef( &__SIO_OD( idp->tied_fd ), idp->tied_fd ) ;
 
-#ifdef HAVE_MMAP
+#ifdef HAS_MMAP
 	if ( idp->memory_mapped )
 	{
 		register mapd_s *mdp = MDP( fd ) ;
@@ -743,7 +748,7 @@ int __sio_readf( idp, fd )
 			return( cc ) ;
 		}
 	}
-#endif /* HAVE_MMAP */
+#endif /* HAS_MMAP */
 
 	for ( ;; )
 	{
@@ -863,7 +868,7 @@ int Sdone( fd )
 			{
 				register __sio_id_t *idp = IDP( dp ) ;
 
-#ifdef HAVE_MMAP
+#ifdef HAS_MMAP
 				if ( idp->memory_mapped )
 				{
 					register mapd_s *mdp = MDP( fd ) ;
@@ -877,7 +882,7 @@ int Sdone( fd )
 					idp->memory_mapped = FALSE ;
 				}
 				else
-#endif	/* HAVE_MMAP */
+#endif	/* HAS_MMAP */
 					free( idp->buf - idp->buffer_size ) ;
 					idp->nextb = idp->end = NULL ;
 			}
@@ -981,7 +986,7 @@ int Smorefds()
 	}
 #endif	/* EVENTS */
 
-#ifdef HAVE_MMAP
+#ifdef HAS_MMAP
 	old_size = n_descriptors * sizeof( mapd_s ) ;
 	new_size = n_fds * sizeof( mapd_s ) ;
 	is_static = ( mmap_descriptors == static_mapd_array ) ;
@@ -989,7 +994,7 @@ int Smorefds()
 	if ( p == NULL )
 		return( SIO_ERR ) ;
 	mmap_descriptors = (mapd_s *) p ;
-#endif	/* HAVE_MMAP */
+#endif	/* HAS_MMAP */
 	
 	old_size = n_descriptors * sizeof( __sio_descriptor_t ) ;
 	new_size = n_fds * sizeof( __sio_descriptor_t ) ;
