@@ -5,17 +5,14 @@
  */
 
 
-static char RCSid[] = "$Id: sprint.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: sprint.c,v 1.5 1995/09/10 18:35:09 chuck Exp $" ;
 
-#include <stdlib.h>
-#include <string.h>
 #include <ctype.h>
+#include <sys/param.h>
 
 #include "sio.h"
 #include "impl.h"
 
-
-
 #ifndef WIDE_INT
 #define WIDE_INT							long
 #endif
@@ -24,8 +21,6 @@ typedef WIDE_INT 							wide_int ;
 typedef unsigned WIDE_INT 				u_wide_int ;
 typedef int 								bool_int ;
 
-PRIVATE char *conv_10( register wide_int num, register bool_int is_unsigned, register bool_int *is_negative, char *buf_end, register int *len );
-
 #define S_NULL								"(null)"
 #define S_NULL_LEN						6
 
@@ -127,7 +122,10 @@ PRIVATE char *conv_10( register wide_int num, register bool_int is_unsigned, reg
  */
 #define PREFIX( str, length, ch )	*--str = ch ; length++ ; has_prefix = YES
 
-
+#if defined(linux) || defined(BSD)
+PRIVATE char *conv_10( register wide_int num , register bool_int is_unsigned ,
+	register bool_int *is_negative , char *buf_end , register int *len ) ;
+#endif
 
 /*
  * Sprint is the equivalent of printf for SIO.
@@ -136,7 +134,10 @@ PRIVATE char *conv_10( register wide_int num, register bool_int is_unsigned, reg
  *     - all floating point arguments are passed as doubles
  */
 /* VARARGS2 */
-int Sprint( int fd, register char *fmt, ...) 
+int Sprint( fd, fmt, va_alist ) 
+	int fd ;
+	register char *fmt ;
+	va_dcl
 {
 	__sio_descriptor_t *dp = &__sio_descriptors[ fd ] ;
 	register __sio_od_t *odp = ODP( dp ) ;
@@ -145,7 +146,7 @@ int Sprint( int fd, register char *fmt, ...)
 
 	IO_SETUP( fd, dp, __SIO_OUTPUT_STREAM, SIO_ERR ) ;
 
-	va_start( ap, fmt ) ;
+	va_start( ap ) ;
 	cc = __sio_converter( odp, fd, fmt, ap ) ;
 	va_end( ap ) ;
 	return( cc ) ;
@@ -155,7 +156,10 @@ int Sprint( int fd, register char *fmt, ...)
 /*
  * This is the equivalent of vfprintf for SIO
  */
-int Sprintv( int fd, char *fmt, va_list ap)
+int Sprintv( fd, fmt, ap )
+	int fd ;
+	char *fmt ;
+	va_list ap ;
 {
 	__sio_descriptor_t *dp = &__sio_descriptors[ fd ] ;
 	register __sio_od_t *odp = ODP( dp ) ;
@@ -185,6 +189,7 @@ PRIVATE char *conv_fp( format, num, add_dp, precision, is_negative, buf, len )
 	int decimal_point ;
 	char *ecvt(), *fcvt() ;
 	char *conv_10() ;
+	char *strcpy() ;
 		
 	if ( format == 'f' )
 		p = fcvt( num, precision, &decimal_point, is_negative ) ;
@@ -412,6 +417,7 @@ int __sio_converter( odp, fd, fmt, ap )
 
 	char *conv_10(), *conv_p2(), *conv_fp() ;
 	char *gcvt() ;
+	char *strchr() ;
 
 
 	sp = odp->nextb ;
