@@ -4,11 +4,13 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: strs.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: strs.c,v 3.1 1993/06/13 02:50:39 panos Exp $" ;
 
 #include <ctype.h>
 #include <memory.h>
-#include <stdarg.h>
+#include <varargs.h>
+
+char *malloc() ;
 
 #include "ss_impl.h"
 
@@ -122,13 +124,13 @@ PRIVATE int init( hp, flags, pattern, patlen )
 
 	if ( SS_MALLOC( hp ) )
 	{
-		SS_PATTERN( hp ) = (char *)malloc( (unsigned)SS_PATLEN( hp ) ) ;
+		SS_PATTERN( hp ) = malloc( (unsigned)SS_PATLEN( hp ) ) ;
 		if ( SS_PATTERN( hp ) == CHAR_NULL )
 		{
 			(void) free( (char *)hp ) ;
 			return( SS_ERR ) ;
 		}
-		(void *) memcpy( SS_PATTERN( hp ), pattern, (int)SS_PATLEN( hp ) ) ;
+		(void) memcpy( SS_PATTERN( hp ), pattern, (int)SS_PATLEN( hp ) ) ;
 	}
 	else
 		SS_PATTERN( hp ) = pattern ;
@@ -150,7 +152,7 @@ PRIVATE int init( hp, flags, pattern, patlen )
 			new_pattern = SS_PATTERN( hp ) ;
 		else
 		{
-			new_pattern = (char *)malloc( (unsigned)SS_PATLEN( hp ) + 1 ) ;
+			new_pattern = malloc( (unsigned)SS_PATLEN( hp ) + 1 ) ;
 			if ( new_pattern == CHAR_NULL )
 				return( SS_ERR ) ;
 			SS_SETMALLOC( hp ) ;			/* clears the STRS_NOMALLOC flag */
@@ -195,7 +197,10 @@ PRIVATE void fini( hp )
 /*
  * Create a search handle
  */
-strs_h strs_setup( int flags, char *pattern, ... )
+strs_h strs_setup( flags, pattern, va_alist )
+	int	flags ;
+	char	*pattern ;
+	va_dcl
 {
 	header_s		*hp ;
 	int			patlen ;
@@ -207,7 +212,7 @@ strs_h strs_setup( int flags, char *pattern, ... )
 	
 	if ( flags & STRS_PATLEN )
 	{
-		va_start( ap, pattern ) ;
+		va_start( ap ) ;
 		patlen = va_arg( ap, int ) ;
 		va_end( ap ) ;
 	}
@@ -259,7 +264,12 @@ char *strs_match( handle, str, len )
 
 
 
-char *strs_search( int flags, char *str, int len, char *pattern, ... )
+char *strs_search( flags, str, len, pattern, va_alist )
+	int	flags ;
+	char	*str ;
+	int	len ;
+	char	*pattern ;			/* NUL-terminated */
+	va_dcl
 {
 	header_s		t_header ;
 	char			*p ;
@@ -268,7 +278,7 @@ char *strs_search( int flags, char *str, int len, char *pattern, ... )
 
 	if ( flags & STRS_PATLEN )
 	{
-		va_start( ap, pattern ) ;
+		va_start( ap ) ;
 		patlen = va_arg( ap, int ) ;
 		va_end( ap ) ;
 	}
