@@ -8,7 +8,7 @@
 #define __TIMER_H
 
 /*
- * $Id: timer.h,v 1.2 1999/10/18 05:19:57 bbraun Exp $
+ * $Id: timer.h,v 4.2 1993/05/06 06:43:55 panos Exp $
  */
 
 #include <sys/time.h>
@@ -50,7 +50,7 @@ struct timer_action
 	void		(*ta_func)() ;
 	void		*ta_arg ;
 	jmp_buf	ta_env ;
-};
+} ;
 
 #ifdef __ARGS
 #undef __ARGS
@@ -64,32 +64,35 @@ struct timer_action
 
 typedef void *timer_h ;
 
-timer_h xtimer_create		__ARGS( ( 
+/* Solaris defines timer_create(3R) itself. */
+#define timer_create internal_timer_create
+
+timer_h timer_create		__ARGS( ( 
 											enum timer_types type,
 											int flags,
 											int *errnop
 										) ) ;
-void xtimer_destroy 		__ARGS( ( timer_h handle ) ) ;
+void timer_destroy 		__ARGS( ( timer_h handle ) ) ;
 
-int xtimer_start 			__ARGS( (
+int timer_start 			__ARGS( (
 											timer_h handle,
 											struct itimerval *itvp,
 											enum timer_times time_type,
 											struct timer_action *ap 
 										) ) ;
-void xtimer_stop 			__ARGS( ( timer_h handle ) ) ;
+void timer_stop 			__ARGS( ( timer_h handle ) ) ;
 
-void xtimer_block 			__ARGS( ( timer_h handle ) ) ;
-void xtimer_unblock 		__ARGS( ( timer_h handle ) ) ;
+void timer_block 			__ARGS( ( timer_h handle ) ) ;
+void timer_unblock 		__ARGS( ( timer_h handle ) ) ;
 
-unsigned xtimer_expirations __ARGS( ( timer_h handle ) ) ;
+unsigned timer_expirations __ARGS( ( timer_h handle ) ) ;
 
-void xtimer_block_all		__ARGS( ( enum timer_types type ) ) ;
-void xtimer_unblock_all	__ARGS( ( enum timer_types type ) ) ;
+void timer_block_all		__ARGS( ( enum timer_types type ) ) ;
+void timer_unblock_all	__ARGS( ( enum timer_types type ) ) ;
 
-char *xtimer_strerr		__ARGS( ( timer_h handle ) ) ;
+char *timer_strerr		__ARGS( ( timer_h handle ) ) ;
 
-extern int xtimer_errno ;
+extern int timer_errno ;
 
 #endif	/* __TIMER_H */
 
