@@ -4,14 +4,17 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: child.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: child.c,v 1.10 1996/01/24 19:29:19 chuck Exp $" ;
 
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <sys/resource.h>
+#include <sys/param.h>
+#ifndef BSD
 #include <sys/wait.h>
 #include <netinet/in.h>
+#endif
 #include <syslog.h>
 #include <errno.h>
 #include <pwd.h>
@@ -34,7 +37,10 @@ void msg() ;
 void msg_suspend() ;
 void msg_resume() ;
 
-extern void redir_handler(struct server *serp);
+#ifdef BSD  		/* fix for getrlimit() problem in BSDI */
+#undef RLIMIT_NOFILE
+#include <unistd.h>
+#endif
 
 /*
  * This function is running in the new process
@@ -82,15 +88,11 @@ PRIVATE void exec_server( serp )
 
 	(void) close( descriptor ) ;
 
-#ifdef solaris
 	if ( debug.on )
 	{
 		msg( LOG_DEBUG, func, "exec( %s ). no control terminal", server ) ;
 		no_control_tty() ;
 	}
-#else
-	no_control_tty() ;
-#endif
 
 #ifdef RLIMIT_NOFILE
 	{
@@ -169,9 +171,7 @@ PRIVATE void set_credentials( scp )
 			 *		initgroups was not being invoked to set the remaining
 			 *		groups appropriately
 			 */
-			/* Solar Designer's groups fix */
-			if ( SC_SPECIFIED( scp, A_USER ) && SC_SPECIFIED( scp, A_GROUPS ) &&
-				scp->sc_groups == YES )
+			if ( SC_SPECIFIED( scp, A_USER ) )
 			{
 				struct passwd *pwd ;
 
@@ -195,15 +195,6 @@ PRIVATE void set_credentials( scp )
 					_exit( 1 ) ;
 				}
 			}
-			else
-			{
-				if ( setgroups( 0, NULL ) )
-				{
-					msg( LOG_ERR, func, "setgroups( 0, NULL ) failed: %m" ) ;
-					msg( LOG_ERR, func, "Your system may require that 'groups = yes' be defined for this service: %s", scp->sc_name);
-					_exit( 1 ) ;
-				}
-			}
 #endif	/* ! NO_INITGROUPS */
 		}
 		else
@@ -234,7 +225,6 @@ void child_process( serp )
 	register struct server *serp ;
 {
 	struct service							*sp = SERVER_SERVICE( serp ) ;
-	connection_s                     *cp = SERVER_CONNECTION( serp ) ;
 	register struct service_config	*scp = SVC_CONF( sp ) ;
 	idresult_e								log_remote_user() ;
 	char										*idresult_explain() ;
@@ -277,23 +267,8 @@ void child_process( serp )
 			(void) nice( SC_NICE( scp ) ) ;
 	}
 
-	/* this is where the server gets executed  -bbraun */
 	if ( ! SC_IS_INTERNAL( scp ) )
-	{
-		if( scp->sc_redir_addr != NULL )
-		{
-			redir_handler( serp );
-		}
-		else
-		{
-#ifndef INET6
-#if defined(HAVE_SETENV)
-			setenv("REMOTE_HOST", inet_ntoa(cp->co_remote_address.sin_addr), 0);
-#endif
-#endif
-			exec_server( serp ) ;
-		}
-	}
+		exec_server( serp ) ;
 	else
 	{
 		char name[ 180 ] ;
@@ -311,23 +286,13 @@ void child_process( serp )
 		else
 		{
 			int namelen = sizeof( name ) - 1 ;		/* leave space for the NUL */
-#ifdef INET6
-			struct sockaddr_in6 *sinp = conn_address( SERVER_CONNECTION( serp ) ) ;
-#else
 			struct sockaddr_in *sinp = conn_address( SERVER_CONNECTION( serp ) ) ;
-#endif
 			int len = strx_nprint( name, namelen,
 										"(%s service) %s", program_name, SC_ID( scp ) ) ;
 			
-#ifdef INET6
-			if ( SC_ACCEPTS_CONNECTIONS( scp ) && !IN6_IS_ADDR_UNSPECIFIED(sinp) )
-				strx_print( INT_NULL, &name[ len ], namelen - len,
-													" %s" , xntoa( *sinp ) ) ;
-#else
 			if ( SC_ACCEPTS_CONNECTIONS( scp ) && sinp != SOCKADDRIN_NULL )
 				strx_print( INT_NULL, &name[ len ], namelen - len,
 													" %s", inet_ntoa( sinp->sin_addr ) ) ;
-#endif
 		}
 		rename_process( name ) ;
 		svc_internal( sp, serp ) ;
@@ -350,22 +315,14 @@ void child_exit()
 		register int pid ;
 		struct server *serp ;
 		
-#ifdef HAVE_WAITPID
-		pid = waitpid( -1, &status, WNOHANG ) ;
-#else
 #if defined( sun ) && defined( lint )
 		pid = wait3( (union wait *)&status, WNOHANG, RUSAGE_NULL ) ;
 #else
 		pid = wait3( &status, WNOHANG, RUSAGE_NULL ) ;
-#endif
 #endif
 
 		if ( debug.on )
-#ifdef HAVE_WAITPID
-			msg( LOG_DEBUG, func, "waitpid returned = %d", pid ) ;
-#else
 			msg( LOG_DEBUG, func, "wait3 returned = %d", pid ) ;
-#endif
 		
 		if ( pid == -1 )
 			if ( errno == EINTR )
