@@ -4,17 +4,15 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: env.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: env.c,v 1.1 1996/01/24 19:29:19 chuck Exp $" ;
 
 #include <syslog.h>
 #include <string.h>
-#include <sys/types.h>
 
 #include "misc.h"
 
 #include "attr.h"
 #include "defs.h"
-#include "config.h"
 #include "sconf.h"
 
 void msg() ;
