@@ -4,11 +4,14 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: intcommon.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: intcommon.c,v 1.3 1995/09/10 18:41:13 chuck Exp $" ;
 
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/socket.h>
+#ifdef linux
+#include <netinet/in.h>
+#endif
 #include <signal.h>
 #include <syslog.h>
 #include <errno.h>
@@ -24,7 +27,6 @@ void exit() ;
 
 void msg() ;
 
-
 void int_fail( ip, syscall )
 	struct intercept *ip ;
 	char *syscall ;
@@ -82,6 +84,19 @@ void int_exit( ip )
 	_exit( (int) PROC_EXITSTATUS( status ) ) ;
 }
 
+#ifdef BSD
+/*
+ * handle child signals, straight from Stevens
+ */
+void child_sighandler()
+{
+	int		pid;
+	union wait	status;
+
+	while((pid = wait3((int *)&status, WNOHANG, (struct rusage *) 0)) > 0)
+		;
+}
+#endif	/* BSD */
 
 /*
  * The ops vector must be installed before invoking this function
@@ -122,11 +137,15 @@ void int_init( ip, serp )
 	/*
 	 * Setup signal handling
 	 */
-	if ( signal( SERVER_EXIT_SIG, int_sighandler ) == SIG_ERR )
+#ifdef BSD
+	if ( (int) signal( SERVER_EXIT_SIG, child_sighandler ) == -1 )
+#else
+	if ( (int) signal( SERVER_EXIT_SIG, int_sighandler ) == -1 )
+#endif	/* BSD */
 		int_fail( ip, "signal" ) ;
-	if ( signal( INTERCEPT_SIG, int_sighandler ) == SIG_ERR )
+	if ( (int) signal( INTERCEPT_SIG, int_sighandler ) == -1 )
 		int_fail( ip, "signal" ) ;
-	if ( signal( SIGTERM, int_sighandler ) == SIG_ERR )
+	if ( (int) signal( SIGTERM, int_sighandler ) == -1 )
 		int_fail( ip, "signal" ) ;
 	
 	/*
@@ -151,20 +170,12 @@ void int_init( ip, serp )
  */
 channel_s *int_newconn( ip, sinp, remote_socket )
 	struct intercept		*ip ;
-#ifdef INET6
-	struct sockaddr_in6	*sinp ;
-#else
 	struct sockaddr_in	*sinp ;
-#endif
 	int						remote_socket ;
 {
 	struct service			*sp			= SERVER_SERVICE( INT_SERVER( ip ) ) ;
 	int						socket_type = SVC_SOCKET_TYPE( sp ) ;
-#ifdef INET6
-	struct sockaddr_in6	*local		= INT_LOCALADDR( ip ) ;
-#else
 	struct sockaddr_in	*local		= INT_LOCALADDR( ip ) ;
-#endif
 	char 						*sid			= SVC_ID( sp ) ;
    channel_s				*chp ;
    int						sd ;
@@ -175,11 +186,7 @@ channel_s *int_newconn( ip, sinp, remote_socket )
 	 *
 	 * XXX:	should we use SC_PROTOVAL to explicitly specify the protocol ?
     */
-#ifdef INET6
-   if ( ( sd = socket( AF_INET6, socket_type, 0 ) ) == -1 )
-#else
    if ( ( sd = socket( AF_INET, socket_type, 0 ) ) == -1 )
-#endif
    {
       msg( LOG_ERR, func,"(intercepting %s) socket creation failed: %m", sid ) ;
       return( CHANNEL_NULL ) ;
@@ -228,11 +235,7 @@ channel_s *int_newconn( ip, sinp, remote_socket )
  */
 channel_s *int_lookupconn( ip, sinp, addr_checked )
 	struct intercept		*ip ;
-#ifdef INET6
-   struct sockaddr_in6	*sinp ;
-#else
    struct sockaddr_in	*sinp ;
-#endif
    bool_int					*addr_checked ;
 {
    register unsigned		u ;
@@ -244,21 +247,12 @@ channel_s *int_lookupconn( ip, sinp, addr_checked )
    {
       register channel_s *chp = CHP( pset_pointer( conntab, u ) ) ;
 
-#ifdef INET6
-      if ( memcmp(&chp->ch_from.sin6_addr, &sinp->sin6_addr, sizeof(sinp->sin6_addr)) == 0 )
-      {
-         *addr_checked = TRUE ;
-         if ( chp->ch_from.sin6_port == sinp->sin6_port )
-            return( chp ) ;
-      }
-#else
       if ( chp->ch_from.sin_addr.s_addr == sinp->sin_addr.s_addr )
       {
          *addr_checked = TRUE ;
          if ( chp->ch_from.sin_port == sinp->sin_port )
             return( chp ) ;
       }
-#endif
    }
    return( CHANNEL_NULL ) ;
 }
