@@ -4,10 +4,13 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: internals.c,v 1.2 1999/10/18 05:21:14 bbraun Exp $" ;
+static char RCSid[] = "$Id: internals.c,v 1.3 1995/09/10 18:41:13 chuck Exp $" ;
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef linux
+#include <sys/time.h>
+#endif
 #include <signal.h>
 #include <time.h>
 #include <fcntl.h>
@@ -23,10 +26,6 @@ static char RCSid[] = "$Id: internals.c,v 1.2 1999/10/18 05:21:14 bbraun Exp $"
 
 extern char program_version[] ;
 
-PRIVATE unsigned thread_check( register struct service *sp,unsigned running_servers, unsigned retry_servers );
-PRIVATE unsigned refcount_check( struct service *sp, unsigned *running_servers, unsigned *retry_servers );
-PRIVATE unsigned service_count_check( register struct service *sp, unsigned running_servers, unsigned retry_servers );
-
 void msg() ;
 
 time_t time() ;
@@ -47,82 +46,6 @@ PRIVATE void dump_services( fd )
 		svc_dump( SP( pset_pointer( SERVICES( ps ), u ) ), fd ) ;
 }
 
-/* Contributed from Steven Stanfield <sstanf@reston.wcom.net> */
-/* leaves out st_atime and st_blksize */
-#define STAT_COMP(x, y) ((x.st_dev == y.st_dev) && (x.st_ino == y.st_ino) && \
-                         (x.st_mode == y.st_mode) && \
-                         (x.st_nlink == y.st_nlink) && \
-                         (x.st_uid == y.st_uid) && (x.st_gid == y.st_gid) && \
-                         (x.st_rdev == y.st_rdev) && \
-                         (x.st_size == y.st_size) && \
-                         (x.st_blocks == y.st_blocks) && \
-                         (x.st_mtime == y.st_mtime) && \
-                         (x.st_ctime == y.st_ctime))
-
-/* Contributed from Steven Stanfield <sstanf@reston.wcom.net> */
-/* Take a stab at opening a file securely. */
-int sec_open(char *fname, int flags, mode_t mode)
-{
-	int fd ;
-	char *func = "sec_open" ;
-	struct stat sb, sbafter;
-	int lstatret;
-	
-	lstatret = lstat(fname, &sb);
-	if( !(lstatret == -1 && errno == ENOENT) && (!S_ISREG(sb.st_mode) ||
-		sb.st_nlink > 1 ))
-	{
-  		msg( LOG_ERR, func, "failed to open %s: maybe a vulnerable link",
-		fname );
-  		return(-1);
-	}
-	
-	if (lstatret == -1) 
-	{  /* File Doesn't exist */
-		if (flags & O_CREAT)
-			/* Do this to make sure file hasn't been created after the lstat */
-			/* NOTE: Linux man page states O_EXCL is broken for NFS file
-		      systems.  Seemed to work though, use NFS with caution.  */
-			fd = open( fname, flags | O_EXCL, mode ) ;
-		else
- 			fd = -1;  /* Didn't request a create, we're outa here. */
-	} else {
-		if (flags & O_TRUNC) {
-			/* This is a limitation at the moment, but it keeps this function
-		  from blasting an existing file that someone could have linked
-		  to another file after the initial lstat. */
- 			msg( LOG_ERR, func, "Can not open existing files for truncation(%s)", fname);
-			return(-1);
-		}
-		fd = open( fname, flags, mode ) ;
-	}
-	if ( fd == -1 )
-	{
-      msg( LOG_ERR, func, "failed to open %s", fname ) ;
-      return(-1);
-   }
-
-   if( (lstatret == 0))
-   {
-      if( fstat(fd, &sbafter) < 0 )
-      {
-         msg( LOG_ERR, func, "Can't stat the file (%s) I just opened!",
-fname);
-         close(fd);
-         return(-1);
-      }
-
-      if  (!STAT_COMP(sb, sbafter)) {
-         msg( LOG_ERR, func, "File: %s, changed after opening!", fname);
-
-         close(fd);
-         return(-1);
-      }
-   }
-   return(fd);
-}
-
-
 
 void dump_internal_state()
 {
@@ -132,16 +55,13 @@ void dump_internal_state()
 	register int fd ;
 	register unsigned u ;
 	char *func = "dump_internal_state" ;
-	struct stat sb, sbafter;
-	int lstatret;
 
-	dump_fd = sec_open( dump_file, O_WRONLY + O_CREAT + O_APPEND, DUMP_FILE_MODE);
+	dump_fd = open( dump_file, O_WRONLY + O_CREAT + O_APPEND, DUMP_FILE_MODE ) ;
 	if ( dump_fd == -1 )
 	{
 		msg( LOG_ERR, func, "failed to open %s: %m", dump_file ) ;
 		return ;
 	}
-	
 	Sbuftype( dump_fd, SIO_LINEBUF ) ;
 
 	/*
@@ -240,6 +160,9 @@ PRIVATE void consistency_check( type )
 	unsigned 				error_count						= 0 ;
 	bool_int 				service_count_check_failed	= FALSE ;
 	char						*func								= "consistency_check" ;
+	PRIVATE unsigned		thread_check() ;
+	PRIVATE unsigned		refcount_check() ;
+	PRIVATE unsigned		service_count_check() ;
 
 	socket_mask_copy = ps.rws.socket_mask ;
 
@@ -535,7 +458,7 @@ static timer_h cc_timer ;			/* consistency check timer */
 
 status_e create_cc_timer()
 {
-	cc_timer = xtimer_create( TIMER_REAL, TIMER_RETURN_ERROR, INT_NULL ) ;
+	cc_timer = timer_create( TIMER_REAL, TIMER_RETURN_ERROR, INT_NULL ) ;
 	return( cc_timer ? OK : FAILED ) ;
 }
 
@@ -564,7 +487,7 @@ void enable_periodic_check( interval )
 	ta.ta_flags = debug.on ? TIMER_BLOCK_SAME : TIMER_NOFLAGS ;
 	ta.ta_func = cc_timer_action ;
 	ta.ta_arg = VOID_NULL ;
-	if ( xtimer_start( cc_timer, &itv, TIMER_RELATIVE, &ta ) == TIMER_ERR )
+	if ( timer_start( cc_timer, &itv, TIMER_RELATIVE, &ta ) == TIMER_ERR )
 	{
 		msg( LOG_ERR, func, "Failed to start concistency timer" ) ;
 		return ;
