@@ -4,7 +4,7 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: itox.c,v 1.3 1999/10/18 05:21:14 bbraun Exp $" ;
+static char RCSid[] = "$Id: itox.c,v 1.5 1995/09/10 18:41:13 chuck Exp $" ;
 
 #define EQ( s1, s2 )					( strcmp( s1, s2 ) == 0 )
 
@@ -16,19 +16,20 @@ static char RCSid[] = "$Id: itox.c,v 1.3 1999/10/18 05:21:14 bbraun Exp $" ;
 #define DAEMON_DIR_OPTION			"-daemon_dir"
 #define TCPD_NAME						"tcpd"
 
-#include <string.h>
+#include <sys/param.h>
 #include "sio.h"
 #include "str.h"
 #include "misc.h"
 
-#ifndef strchr
-char *strchr() ;
+#if defined(linux) || defined(BSD)
+PRIVATE void print_line( char *name, char *value ) ;
+PRIVATE char *next_word( char *description ) ;
 #endif
 
+char *strchr() ;
+
 str_h strp ;
 int line_count ;
-PRIVATE void print_line( char *name, char *value );
-PRIVATE char *next_word( char *description );
 
 /*
  * This program works only as a filter.
@@ -110,30 +111,10 @@ int main( argc, argv )
 		print_line( "protocol", protocol ) ;
 
 		word = next_word( "wait/nowait" ) ;
-		p = strchr(word, '.');
-		if (p != NULL)
-		{
-			Sprint( 2, "The entry for service %s/%s may be wrong, because\n", service, protocol);
-			Sprint( 2, "we can't convert .max option for wait/nowait fiel
-d\n" ) ;
-			*p = '\0';
-			print_line( "wait", EQ( word, "wait" ) ? "yes" : "no" ) ;
-		}
-		else
-			print_line( "wait", EQ( word, "wait" ) ? "yes" : "no" ) ;
+		print_line( "wait", EQ( word, "wait" ) ? "yes" : "no" ) ;
 
-
-		word = next_word( "user[.group]" ) ;
-		p = strchr(word, '.');
-		if (p != NULL)
-		{
-			*p = '\0';
-			print_line( "user", word ) ;
-			word = ++p;
-			print_line( "group", word );
-		}
-		else
-			print_line( "user", word ) ;
+		word = next_word( "user" ) ;
+		print_line( "user", word ) ;
 
 		word = next_word( "server" ) ;
 		if ( EQ( word, "internal" ) )
@@ -156,7 +137,7 @@ d\n" ) ;
 		else
 		{
 			char *server_path = word ;		/* from inetd.conf */
-			char *server_of_server_path = (char *)basename( server_path ) ;
+			char *server_of_server_path = basename( server_path ) ;
 			char *server_name = next_word( "server name" ) ;
 			char *server ;						/* for xinetd config file */
 
