@@ -4,13 +4,17 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: log.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: log.c,v 1.7 1996/01/24 19:29:19 chuck Exp $" ;
+
+#include <syslog.h>
+#include <time.h>
 
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <sys/param.h>
+#ifndef BSD
 #include <sys/wait.h>
-#include <syslog.h>
-#include <time.h>
+#endif
 
 #include "sio.h"
 #include "str.h"
@@ -21,11 +25,6 @@ static char RCSid[] = "$Id: log.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
 #include "sconst.h"
 #include "service.h"
 #include "server.h"
-#include "config.h"
-
-#if !defined(HAVE_SNPRINTF)
-extern int      snprintf(char *, size_t, const char *, ...);
-#endif
 
 
 void msg() ;
@@ -35,40 +34,6 @@ void msg() ;
 
 time_t time() ;
 
-struct xaddr
-{
-	unsigned char a;
-	unsigned char b;
-	unsigned char c;
-	unsigned char d;
-};
-
-#ifdef INET6
-char *xntoa(struct sockaddr_in6 inaddr)
-#else
-char *xntoa(struct sockaddr_in inaddr)
-#endif
-{
-#ifdef INET6
-	char *tmp = malloc(128);
-	if( tmp == NULL )
-		return "NULL";
-
-	inet_ntop(AF_INET6, &( ((struct sockaddr_in6 *)&inaddr)->sin6_addr), tmp, 128);
-
-	return tmp;
-#else
-	char *tmp;
-	struct xaddr foo;
-	bcopy(&(inaddr.sin_addr), &foo, 4);
-	tmp = (char *)malloc(16);
-
-	snprintf(tmp, 16, "%d.%d.%d.%d", foo.a, foo.b, foo.c, foo.d);
-	return tmp;
-#endif
-
-}
-
 
 PRIVATE int log_common() ;
 
@@ -87,7 +52,6 @@ void svc_log_success( sp, cp, pid )
 	register struct service_config	*scp = SVC_CONF( sp ) ;
 	register int							len ;
 	register int							cc ;
-	char *foo;
 
 	if ( ! SVC_LOGS_ON_SUCCESS( sp ) )
 		return ;
@@ -256,7 +220,11 @@ void svc_log_exit( sp, serp )
  * going through the proper channels (i.e. log_{success,failure} and log_exit)
  */
 /* VARARGS3 */
-void svc_logprint( register struct service *sp, char *line_id, char *fmt, ...)
+void svc_logprint( sp, line_id, fmt, va_alist )
+	register struct service	*sp ;
+	char							*line_id ;
+	char							*fmt ;
+	va_dcl
 {
 	char		buf[ LOGBUF_SIZE ] ;
 	int		bufsize = sizeof( buf ) ;
@@ -268,7 +236,7 @@ void svc_logprint( register struct service *sp, char *line_id, char *fmt, ...)
 		return ;
 
 	len = strx_nprint( buf, bufsize, "%s: %s ", line_id, SVC_ID( sp ) ) ;
-	va_start( ap, fmt ) ;
+	va_start( ap ) ;
 	cc = strx_nprintv( &buf[ len ], bufsize, fmt, ap ) ;
 	va_end( ap ) ;
 	xlog_write( sp->svc_log, buf, len+cc, XLOG_NO_SIZECHECK ) ;
