@@ -23,6 +23,7 @@ extern int shutdownprocs_option ;
 extern unsigned shutdownprocs_option_arg_1 ;
 extern int cc_option ;
 extern unsigned cc_option_arg_1 ;
+extern u_long host_option_arg_1;
 
 #define f_option_arg                   f_option_arg_1
 #define filelog_option_arg             filelog_option_arg_1
@@ -32,6 +33,7 @@ extern unsigned cc_option_arg_1 ;
 #define logprocs_option_arg            logprocs_option_arg_1
 #define shutdownprocs_option_arg       shutdownprocs_option_arg_1
 #define cc_option_arg                  cc_option_arg_1
+#define host_option_arg		       host_option_arg_1
 
 extern char *program_name ;
 
