@@ -4,7 +4,9 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: parsers.c,v 1.5 1999/10/14 23:46:27 bbraun Exp $" ;
+static char RCSid[] = "$Id: parsers.c,v 1.3 1995/09/10 18:41:13 chuck Exp $" ;
+
+#include <unistd.h>
 
 #include <sys/file.h>
 #include <syslog.h>
@@ -12,16 +14,7 @@ static char RCSid[] = "$Id: parsers.c,v 1.5 1999/10/14 23:46:27 bbraun Exp $" ;
 #include <netdb.h>
 #include <pwd.h>
 #include <grp.h>
-#include <sys/types.h>
 #include <netinet/in.h>
-#include <arpa/inet.h>
-#include <unistd.h>
-#include <limits.h> /* For LONG_MIN and LONG_MAX */
-
-#if defined(hpux) && !defined(X_OK)
-#define X_OK 1
-#endif
-
 
 int free() ;
 
@@ -34,13 +27,14 @@ int free() ;
 #include "config.h"
 #include "addr.h"
 
-#define NEW_SET( set, v1, v2 )                 \
-	if ( (set) == NULL && \
-	( (set) = pset_create( (set), (v1), (v2) ) ) == NULL )	\
-	{	\
-		out_of_memory( func ) ;	\
-		return( FAILED ) ;	\
-	}
+#define NEW_SET( set, v1, v2 )												\
+				if ( (set) == NULL && 										\
+					( (set) = pset_create( (set), (v1), (v2) ) ) == NULL )	\
+				{															\
+					out_of_memory( func ) ;									\
+					return( FAILED ) ;										\
+				}
+
 
 void msg() ;
 void parsemsg() ;
@@ -107,7 +101,7 @@ status_e flags_parser( values, scp, op )
 	enum assign_op op ;
 {
 	return( parse_value_list( values,
-						&scp->sc_xflags, service_flags, PLUS_EQ, "service flag" ) ) ;
+						&scp->sc_flags, service_flags, PLUS_EQ, "service flag" ) ) ;
 }
 
 
@@ -260,22 +254,7 @@ status_e group_parser( values, scp, op )
 	return( OK ) ;
 }
 
-status_e groups_parser( values, scp, op )
-	pset_h values ;
-	struct service_config *scp ;
-	enum assign_op op ;
-{
-	char *val = (char *) pset_pointer( values, 0 ) ;
-	char *func = "groups_parser" ;
 
-	if ( EQ( val, "yes" ) )
-		scp->sc_groups = YES ;
-	else if ( EQ( val, "no" ) )
-		scp->sc_groups = NO ;
-	else
-		parsemsg( LOG_ERR, func, "Bad value for groups: %s", val ) ;
-	return( OK );
-}
 
 status_e server_parser( values, scp, op )
 	pset_h values ;
@@ -321,45 +300,74 @@ status_e server_args_parser( values, scp, op )
 	 */
 	argv = argv_alloc( n_args+1 ) ;
 	
-	if( SC_NAMEINARGS( scp ) )
+	for ( u = 0, argv_index = 1 ; u < pset_count( values ) ; u++, argv_index++ )
 	{
-		for (u = 0; u < pset_count( values ) ; u++)
-		{
-			register char *s = make_string(1, (char *) pset_pointer( values, u )) ;
+		register char *s = make_string( 1, (char *) pset_pointer( values, u ) ) ;
 
-			if ( s == NULL )
-			{
- 				for ( i = 1 ; i < u ; i++ )
-					free( argv[ i ] ) ;
-				free( (char *) argv ) ;
- 				out_of_memory( func ) ;
- 				return( FAILED ) ;
-			}
-			argv[ u ] = s ;
-		}
-	}
-	else
-	{
-		for (u = 0, argv_index = 1 ; u < pset_count( values ) ; u++, argv_index++)
+		if ( s == NULL )
 		{
-			register char *s = make_string(1, (char *) pset_pointer( values, u )) ;
-
-			if ( s == NULL )
-			{
- 				for ( i = 1 ; i < argv_index ; i++ )
-					free( argv[ i ] ) ;
-				free( (char *) argv ) ;
- 				out_of_memory( func ) ;
- 				return( FAILED ) ;
-			}
-			argv[ argv_index ] = s ;
+			for ( i = 1 ; i < argv_index ; i++ )
+				free( argv[ i ] ) ;
+			free( (char *) argv ) ;
+			out_of_memory( func ) ;
+			return( FAILED ) ;
 		}
-		argv[ argv_index ] = argv[ 0 ] = NULL ;
+		argv[ argv_index ] = s ;
 	}
+
+	argv[ argv_index ] = argv[ 0 ] = NULL ;
 	scp->sc_server_argv = argv ;
 	return( OK ) ;
 }
 
+int  host_parser ( name, host) /* to alternativly use IP-# or hostname */
+     char*	name;
+     u_long*	host;
+{
+     if (name)
+     {
+         u_long addr;			/* first try numeric address */
+	 addr = inet_addr(name);
+	 if (addr == -1)		/* canonical hostname */
+	 {
+	     struct hostent* hp;
+	     hp = gethostbyname (name);
+	     if (hp)
+	     {
+		 *host = ntohl(*((u_long*) hp->h_addr_list[0]));
+	     }
+	     else
+	       return 0;
+	 } else
+	   *host = ntohl(addr);
+     } else
+       return 0; /* should not occur (calling bug in source) */
+     return 1;
+}
+	     
+/* parsing routine for interface IP address */
+status_e interface_parser( values, scp, op )
+	pset_h values ;
+	struct service_config *scp ;
+	enum assign_op op ;
+{
+	char   *interface = (char *) pset_pointer( values, 0 ) ;
+	char   *func      = "interface_parser" ;
+	u_long host	  = INADDR_ANY;
+
+	if (!host_parser (interface, &host))
+	{
+	    parsemsg( LOG_ERR, func,
+		      "Badly formed interface address or unknown host: %s", 
+		      interface ) ;
+	    return (FAILED);
+	}
+	
+	/* assign an IP address */
+	scp->sc_interface.s_addr = htonl(host);
+
+	return ( OK );
+}
 
 status_e instances_parser( values, scp, op )
 	pset_h values ;
@@ -373,77 +381,17 @@ status_e instances_parser( values, scp, op )
 		scp->sc_instances = UNLIMITED ;
 	else
 	{
-		scp->sc_instances = atoi( instances ) ;
-		if ( scp->sc_instances < 0 )
-		{
-			parsemsg( LOG_ERR, func,
-				"Number of instances is negative: %s", instances ) ;
-			return( FAILED ) ;
-		}
+	    scp->sc_instances = atoi( instances ) ;
+	    if ( scp->sc_instances < 0 )
+	    {
+		parsemsg( LOG_ERR, func,
+			  "Number of instances is negative: %s", instances ) ;
+		return( FAILED ) ;
+	    }
 	}
 	return( OK ) ;
 }
 
-status_e per_source_parser( values, scp, op )
-	pset_h values ;
-	struct service_config *scp ;
-	enum assign_op op ;
-{
-	char *per_source = (char *) pset_pointer( values, 0 ) ;
-	char *func = "per_source_parser" ;
-
-	if ( EQ( per_source, "UNLIMITED" ) )
-		scp->sc_per_source = UNLIMITED;
-	else
-	{
-		scp->sc_per_source = atoi( per_source ) ;
-		if ( scp->sc_per_source < 0 )
-		{
-			parsemsg( LOG_ERR, func, "Number of per source instances is negative: %s", per_source ) ;
-			return( FAILED );
-		}
-	}
-	return(OK);
-}
-
-status_e cps_parser( values, scp, op )
-	pset_h values ;
-	struct service_config *scp ;
-	enum assign_op op ;
-{
-	char *cps = (char *) pset_pointer(values, 0);
-	char *waittime = (char *) pset_pointer(values, 1);
-
-	if( cps == NULL || waittime == NULL ) {
-		parsemsg(LOG_ERR, "cps_parser", "NULL options specified in cps\n");
-		return( FAILED );
-	}
-	scp->sc_time_conn_max = strtol(cps, NULL, 10);
-	if( scp->sc_time_conn_max == LONG_MIN || 
-		scp->sc_time_conn_max == LONG_MAX ) {
-
-		parsemsg(LOG_ERR, "cps_parser", "cps arguement not a number\n");
-		scp->sc_time_conn_max = 0;
-		scp->sc_time_wait = 0;
-		return(FAILED);
-	}
-	scp->sc_time_wait = strtol(waittime, NULL, 10);
-	if( scp->sc_time_wait == LONG_MIN || scp->sc_time_wait == LONG_MAX ) {
-		parsemsg(LOG_ERR, "cps_parser", "cps time arguement not a number\n");
-		scp->sc_time_conn_max = 0;
-		scp->sc_time_wait = 0;
-		return(FAILED);
-	}
-
-	if( scp->sc_time_conn_max < 0 || scp->sc_time_wait < 0 ) {
-		parsemsg(LOG_ERR, "cps_parser", "cps arguements invalid\n");
-		scp->sc_time_conn_max = 0;
-		scp->sc_time_wait = 0;
-		return(FAILED);
-	}
-
-	return(OK);
-}
 
 status_e id_parser( values, scp, op )
 	pset_h values ;
@@ -630,27 +578,6 @@ status_e disabled_parser( values, scp, op )
 }
 
 
-status_e enabled_parser( values, scp, op )
-	pset_h values ;
-	struct service_config *scp ;
-	enum assign_op op ;
-{
-	register unsigned u ;
-	char *func = "enabled_parser" ;
-
-	NEW_SET( scp->sc_enabled, pset_count( values ), 0 ) ;
-	
-	for ( u = 0 ; u < pset_count( values ) ; u++ )
-	{
-		char *name = (char *) pset_pointer( values, u ) ;
-
-		if ( add_new_string( scp->sc_enabled, name ) == FAILED )
-			return( OK ) ;
-syslog(LOG_ERR, "added %s\n", name);
-	}
-	return( OK ) ;
-}
-
 /*
  * Interpret a number of the form: <num>[m|M|k|K]
  * m and M mean megabytes, k and K mean kilobytes, nothing means bytes
@@ -870,10 +797,10 @@ PRIVATE status_e parse_inet_addresses( values, op, addr_list )
 	enum assign_op op ;
 	pset_h			*addr_list ;
 {
-	register unsigned		u ;
-	pset_h					addr_set ;
-	statfunc					addrlist_func ;
-	char						*func = "parse_inet_addresses" ;
+	register unsigned	u ;
+	pset_h			addr_set ;
+	statfunc		addrlist_func ;
+	char			*func = "parse_inet_addresses" ;
 	
 	NEW_SET( *addr_list, 0, 0 ) ;
 
@@ -920,291 +847,6 @@ status_e no_access_parser( values, scp, op )
 	return( parse_inet_addresses( values, op, &scp->sc_no_access ) ) ;
 }
 
-status_e banner_parser(pset_h values, struct service_config *scp, enum assign_op op)
-{
-	char *func = "banner_parser";
-
-	if( pset_pointer(values, 0) == NULL )
-	{
-		msg(LOG_ERR, func, "%s: pset_pointer returned null\n", func);
-		return FAILED;
-	}
-
-	scp->sc_banner = (char *)malloc(strlen(pset_pointer(values,0))+1);
-	if( scp->sc_banner == NULL ) {
-		msg(LOG_ERR, func, "%s: Out of memory\n", func);
-		return FAILED;
-	}
-
-	bzero(scp->sc_banner, strlen(pset_pointer(values,0))+1);
-
-	strcpy(scp->sc_banner, pset_pointer(values,0));
-
-	return OK;
-}
-
-status_e banner_success_parser(pset_h values, struct service_config *scp, enum assign_op op)
-{
-	char *func = "banner_success_parser";
-
-	if( pset_pointer(values, 0) == NULL ) {
-		msg(LOG_ERR, func, "%s: pset_pointer returned null.\n", func);
-		return FAILED;
-	}
-
-	scp->sc_banner_success = (char *)malloc(strlen(pset_pointer(values,0))+1);
-	if( scp->sc_banner_success == NULL ) {
-		msg(LOG_ERR, func, "%s: Out of memory.\n", func);
-		return FAILED;
-	}
-
-	bzero(scp->sc_banner_success, strlen(pset_pointer(values,0))+1);
-
-	strcpy(scp->sc_banner_success, pset_pointer(values,0));
-	return OK;
-}
-
-status_e banner_fail_parser(pset_h values, struct service_config *scp, enum assign_op op)
-{
-	char *func = "banner_fail_parser";
-
-	if( pset_pointer(values, 0) == NULL ) {
-		msg(LOG_ERR, func, "%s: pset_pointer returned NULL\n", func);
-		return FAILED;
-	}
-
-	scp->sc_banner_fail = (char *)malloc(strlen(pset_pointer(values,0))+1);
-	if( scp->sc_banner_fail == NULL ) {
-		msg(LOG_ERR, func, "%s: Out of memory\n", func);
-		return FAILED;
-	}
-	bzero(scp->sc_banner_fail, strlen(pset_pointer(values,0))+1);
-	
-	strcpy(scp->sc_banner_fail, pset_pointer(values,0));
-
-	return OK;
-}
-
-#ifdef HAVE_LOADAVG
-status_e max_load_parser(pset_h values, struct service_config *scp, enum assign_op op)
-{
-	char *func = "max_load_parser" ;
-	char *adr = (char *)pset_pointer(values, 0);
-
-	if( sscanf(adr, "%lf", &scp->sc_max_load) < 1 ) {
-		msg(LOG_ERR, func, "error reading max_load argument\n");
-		return FAILED;
-	}
-
-	if( scp->sc_max_load == 0 ) {
-		msg(LOG_ERR, func, "error parsing max_load arguement\n");
-		return FAILED;
-	}
-
-	return OK;
-}
-#endif
-
-status_e redir_parser(pset_h values, struct service_config *scp, enum assign_op op)
-{
-	char *adr = (char *)pset_pointer(values, 0);
-	char *foo;
-	char *uptmp;
-#ifdef INET6
-	char v6addr[46];
-	struct addrinfo hints, *res, *ressave;
-	int n;
-	char *func="redir_parser";
-	char *xaddrmap(char *, char *);
-
-	uptmp = pset_pointer(values, 1);
-	scp->sc_redir_port = strtol(uptmp, NULL, 10);
-
-	scp->sc_redir_addr = (struct in6_addr *)malloc(sizeof(struct in6_addr));
-
-	if( scp->sc_redir_addr == NULL )
-	{
-		msg(LOG_ERR, func, "%s: can't allocate space for redir addr\n", func);
-		return FAILED;
-	}
-
-	bzero(&hints, sizeof(hints));
-	hints.ai_flags = AI_CANONNAME;
-	hints.ai_family = AF_INET6;
-
-	if( (n = getaddrinfo(adr, NULL, &hints, &res)) < 0 ) {
-		hints.ai_family = AF_INET;
-		if( (n = getaddrinfo(adr, NULL, &hints, &res ) ) < 0 ) {
-			msg(LOG_ERR, func, "%s: Trying IPv4 name failed\n", func);
-			return FAILED;
-		}
-
-		bzero(v6addr, 46);
-		hints.ai_family = AF_INET6;
-		xaddrmap(inet_ntoa( ((struct sockaddr_in *)(res->ai_addr))->sin_addr), v6addr);
-		freeaddrinfo(res);
-
-		if( (n = getaddrinfo(v6addr, NULL, &hints, &res)) < 0 ) {
-			msg(LOG_ERR, func, "%s: bad address", func);
-			return FAILED;
-		}
-	}
-
-	if( (res == NULL) || (res->ai_addr == NULL) ) {
-		msg(LOG_ERR, func, "%s: no addresses returned", func);
-		return FAILED;
-	}
-		
-	memcpy(scp->sc_redir_addr, &((struct sockaddr_in6 *)res->ai_addr)->sin6_addr, sizeof(struct in6_addr));
-
-	return OK;
-
-#else
-	unsigned long tempaddr;
-	struct hostent *he;
-
-	uptmp = pset_pointer(values, 1);
-
-	scp->sc_redir_port = strtol(uptmp, NULL, 10);
-
-	scp->sc_redir_addr = (struct in_addr *)malloc(sizeof(struct in_addr));
-
-	if( scp->sc_redir_addr == NULL )
-	{
-		syslog(LOG_ERR, "redir_parser: can't allocate space for redir addr\n");
-		return FAILED;
-	}
-
-	he = gethostbyname(adr);
-	if( he == NULL )
-	{
-#if defined(NO_INET_ATON)
-		tempaddr = inet_addr(adr);
-		bcopy(&tempaddr, scp->sc_redir_addr, sizeof(tempaddr));
-#else
-		if( inet_aton(adr, scp->sc_redir_addr) < 1 )
-		{
-			syslog(LOG_ERR, "redir_parser: invalid IP address %s\n", adr);
-			free(scp->sc_redir_addr);
-			return FAILED;
-		}
-#endif
-	}
-	else
-	{
-		/* gethostbyname succeeded */
-		bcopy(he->h_addr, scp->sc_redir_addr, sizeof(he->h_addr));
-	}
-
-	foo = inet_ntoa(*scp->sc_redir_addr);
-
-	if( foo == NULL )
-	{
-		syslog(LOG_ERR, "inet_ntoa failed\n");
-		free(scp->sc_redir_addr);
-		return FAILED;
-	}
-
-	return OK;
-#endif /* INET6 */
-}
-
-status_e bind_parser( pset_h values, struct service_config *scp, enum assign_op op)
-{
-	char *adr = (char *)pset_pointer(values, 0);
-	char *foo;
-	unsigned long tempaddr;
-	char *func = "bind_parser";
-#ifdef INET6
-	int n;
-	char v6addr[46];
-	struct addrinfo hints, *res;
-	char *xaddrmap(char *, char *);
-
-	scp->sc_bind_addr = (struct in6_addr *)malloc(sizeof(struct in6_addr));
-
-	if( scp->sc_bind_addr == NULL )
-	{
-		msg(LOG_ERR, func, "%s: can't allocate space for bind addr\n", func);
-		return FAILED;
-	}
-
-	bzero(&hints, sizeof(hints));
-	hints.ai_flags = AI_CANONNAME;
-	hints.ai_family = AF_INET6;
-
-	if( (n = getaddrinfo(adr, NULL, &hints, &res ) ) < 0 ) {
-		hints.ai_family = AF_INET;
-		if( (n = getaddrinfo(adr, NULL, &hints, &res ) ) < 0 ) {
-			msg(LOG_ERR, func, "%s: Trying IPv4 name failed\n", func);
-			return FAILED;
-		}
-
-		bzero(v6addr, 46);
-		hints.ai_family = AF_INET6;
-		xaddrmap(inet_ntoa( ((struct sockaddr_in *)(res->ai_addr))->sin_addr), v6addr);
-		freeaddrinfo(res);
-
-		if( (n = getaddrinfo(v6addr, NULL, &hints, &res ) ) < 0 ) {
-			msg(LOG_ERR, func, "%s: bad address", func);
-			return FAILED;
-		}
-	}
-
-	if( ( res == NULL ) || ( res->ai_addr == NULL ) ) {
-		msg(LOG_ERR, func, "%s: no addresses returned", func);
-		return FAILED;
-	}
-
-	memcpy(scp->sc_bind_addr, &((struct sockaddr_in6 *)(res->ai_addr))->sin6_addr, sizeof(struct in6_addr));
-
-	freeaddrinfo(res);
-	return OK;
-#else
-	struct hostent *he;
-
-	scp->sc_bind_addr = (struct in_addr *)malloc(sizeof(struct in_addr));
-
-	if( scp->sc_bind_addr == NULL )
-	{
-		syslog(LOG_ERR, "bind_parser: can't allocate space for bind addr\n");
-		return FAILED;
-	}
-
-	he = gethostbyname(adr);
-	if( he == NULL )
-	{
-#if defined(NO_INET_ATON)
-		tempaddr = inet_addr(adr);
-		bcopy(&tempaddr, scp->sc_bind_addr, sizeof(tempaddr));
-#else
-		if( inet_aton(adr, scp->sc_bind_addr) < 1 )
-		{
-			syslog(LOG_ERR, "bind_parser: invalid IP address %s\n", adr);
-			free(scp->sc_bind_addr);
-			return FAILED;
-		}
-#endif
-	}
-	else
-	{
-		/* gethostbyname succeeded, so we now have the address */
-		bcopy(he->h_addr, scp->sc_bind_addr, sizeof(he->h_addr));
-	}
-
-	foo = inet_ntoa(*scp->sc_bind_addr);
-
-	if( foo == NULL )
-	{
-		syslog(LOG_ERR, "inet_ntoa failed\n");
-		free(scp->sc_bind_addr);
-		return FAILED;
-	}
-	
-	return OK;
-#endif /* INET6 */
-	
-}
 
 status_e access_times_parser( values, scp, op )
 	pset_h values ;
