@@ -4,7 +4,12 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: sconf.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: sconf.c,v 1.2 1995/09/10 14:26:36 chuck Exp $" ;
+
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #include "misc.h"
 
@@ -172,7 +177,7 @@ struct service_config *sc_make_special( service_name, bp, instances )
 	scp->sc_builtin = bp ;
    SC_SPECIFY( scp, A_TYPE ) ;
 
-   M_SET( scp->sc_xflags, SF_NORETRY ) ;
+   M_SET( scp->sc_flags, SF_NORETRY ) ;
    SC_SPECIFY( scp, A_FLAGS ) ;
 
    scp->sc_instances = instances ;
@@ -261,11 +266,11 @@ void sc_dump( scp, fd, tab_level, is_defaults )
 	{
 		tabprint( fd, tab_level+1, "id = %s\n", scp->sc_id ) ;
 
-		if ( ! M_ARE_ALL_CLEAR( scp->sc_xflags ) )
+		if ( ! M_ARE_ALL_CLEAR( scp->sc_flags ) )
 		{
 			tabprint( fd, tab_level+1, "flags =" ) ;
 			for ( nvp = &service_flags[ 0 ] ; nvp->name != NULL ; nvp++ )
-				if ( M_IS_SET( scp->sc_xflags, nvp->value ) )
+				if ( M_IS_SET( scp->sc_flags, nvp->value ) )
 					Sprint( fd, " %s", nvp->name ) ;
 			Sputchar( fd, '\n' ) ;
 		}
@@ -288,7 +293,13 @@ void sc_dump( scp, fd, tab_level, is_defaults )
 		tabprint( fd, tab_level+1, "Protocol (name,number) = (%s,%d)\n",
 				scp->sc_protocol.name, scp->sc_protocol.value ) ;
 	}
-
+	
+	if (scp->sc_interface.s_addr == 0)
+	  tabprint( fd, tab_level+1, "Interface = INADDR_ANY\n");
+	else
+	  tabprint( fd, tab_level+1, "Interface = %s\n",
+		    inet_ntoa( scp->sc_interface ) ) ;
+	
 	if ( SC_SPECIFIED( scp, A_INSTANCES ) )
 		if ( scp->sc_instances == UNLIMITED )
 			tabprint( fd, tab_level+1, "Instances = UNLIMITED\n" ) ;
@@ -403,27 +414,35 @@ void sc_dump( scp, fd, tab_level, is_defaults )
 bool_int sc_different_confs( scp1, scp2 )
 	struct service_config *scp1, *scp2 ;
 {
-   if ( SC_IS_UNLISTED( scp1 ) != SC_IS_UNLISTED( scp2 ) ||
-				SC_IS_INTERNAL( scp1 ) != SC_IS_INTERNAL( scp2 ) ||
-					SC_IS_RPC( scp1 ) != SC_IS_RPC( scp2 ) )
-      return( TRUE ) ;
+    if ( SC_IS_UNLISTED( scp1 ) != SC_IS_UNLISTED( scp2 ) ||
+       SC_IS_INTERNAL( scp1 ) != SC_IS_INTERNAL( scp2 ) ||
+       SC_IS_RPC( scp1 ) != SC_IS_RPC( scp2 ) )
+        return( TRUE ) ;
 
-   if ( scp1->sc_wait != scp2->sc_wait )
-      return( TRUE ) ;
+    if ( scp1->sc_wait != scp2->sc_wait )
+        return( TRUE ) ;
   
-	if ( scp1->sc_protocol.value != scp2->sc_protocol.value )
-      return( TRUE ) ;
+    if ( scp1->sc_protocol.value != scp2->sc_protocol.value )
+        return( TRUE ) ;
 
-   if ( SC_IS_RPC( scp1 ) )
-   {
-		if ( ! SAME_RPC( scp1, scp2 ) )
-         return( TRUE ) ;
-   }
-   else
-   {
-		if ( ! SAME_NONRPC( scp1, scp2 ) )
-         return( TRUE ) ;
-   }
-   return( FALSE ) ;
+    /* added to check if IP addresses are different.
+     * by default we stop all instances of a server if it
+     * is to rebind to another interface or if it is 
+     * disabled from an interface
+     */
+    if ( scp1->sc_interface.s_addr != scp2->sc_interface.s_addr )
+        return( TRUE ) ;
+
+    if ( SC_IS_RPC( scp1 ) )
+    {
+      if ( ! SAME_RPC( scp1, scp2 ) )
+	return( TRUE ) ;
+    }
+    else
+    {
+      if ( ! SAME_NONRPC( scp1, scp2 ) )
+	return( TRUE ) ;
+    }
+    return( FALSE ) ;
 }
 
