@@ -4,18 +4,15 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: server.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: server.c,v 1.1 1996/01/24 19:29:19 chuck Exp $" ;
 
 #include <sys/types.h>
+#include <sys/file.h>
 #include <sys/socket.h>
 #include <syslog.h>
 #include <fcntl.h>
 #include <time.h>
 
-#ifdef HAVE_SYS_FILE_H
-#include <sys/file.h>
-#endif
-
 #include "sio.h"
 
 #include "state.h"
