@@ -8,14 +8,16 @@
 #define SERVER_H
 
 /*
- * $Id: server.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: server.h,v 1.2 1995/09/10 15:42:38 chuck Exp $
  */
 
 #include <sys/types.h>
 #include <sys/wait.h>
 
 #include "defs.h"
+#ifdef BSD
 #include "service.h"
+#endif
 #include "connection.h"
 
 #ifdef NO_POSIX_TYPES
@@ -43,7 +45,7 @@ struct server
 #define SERP( p )                		((struct server *)(p))
 
 #define SERVER_SERVICE( serp )			(serp)->svr_sp
-#define SERVER_CONNECTION( serp)			(connection_s *)(serp)->svr_conn
+#define SERVER_CONNECTION( serp)			(serp)->svr_conn
 #define SERVER_CONNSERVICE( serp )		CONN_SERVICE( SERVER_CONNECTION( serp ) )
 #define SERVER_FD( serp )					CONN_DESCRIPTOR( (serp)->svr_conn )
 #define SERVER_PID( serp )					(serp)->svr_pid
