@@ -8,16 +8,11 @@
 #define STATE_H
 
 /*
- * $Id: state.h,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $
+ * $Id: state.h,v 1.1 1996/01/24 19:29:19 chuck Exp $
  */
 
 #include <setjmp.h>
 
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/types.h>
-#include <sys/select.h>
-#endif
-
 #include "pset.h"
 #include "xlog.h"
 
