@@ -4,19 +4,18 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: tcpint.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: tcpint.c,v 1.2 1995/09/10 18:41:13 chuck Exp $" ;
 
 #include <sys/types.h>
 #include <sys/socket.h>
+#ifdef linux
+#include <netinet/in.h>
+#endif
 #include <sys/time.h>
 #include <syslog.h>
 #include <signal.h>
 #include <errno.h>
 
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
-
 #include "config.h"
 #include "int.h"
 #include "access.h"
@@ -25,7 +24,6 @@ static char RCSid[] = "$Id: tcpint.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $"
 char *inet_ntoa() ;
 void msg() ;
 
-
 typedef enum { S_OK, S_SERVER_ERR, S_CLIENT_ERR } stream_status_e ;
 
 struct istream_private
@@ -58,15 +56,11 @@ struct intercept *si_init( serp )
 	ip->int_priv = (void *) &istream ;
 	ip->int_ops = &istream_ops ;
 	int_init( ip, serp ) ;
-	if ( signal( SIGPIPE, SIG_IGN ) == SIG_ERR )
+	if ( (int) signal( SIGPIPE, SIG_IGN ) == -1 )
 		int_fail( ip, "signal" ) ;
 	return( ip ) ;
 }
 
-PRIVATE status_e handle_io( psi_h iter, channel_s *chp, fd_set *maskp, stream_status_e (*iofunc)() );
-PRIVATE stream_status_e tcp_local_to_remote( channel_s *chp );
-PRIVATE stream_status_e tcp_remote_to_local( channel_s *chp );
-PRIVATE void connection_request( struct intercept *ip, channel_s **chpp );
 
 PRIVATE void si_exit()
 {
@@ -85,6 +79,10 @@ PRIVATE void si_mux()
 	int								mask_max ;
 	psi_h								iter ;
 	char								*func = "si_mux" ;
+	PRIVATE status_e				handle_io() ;
+	PRIVATE stream_status_e		tcp_local_to_remote() ;
+	PRIVATE stream_status_e		tcp_remote_to_local() ;
+	PRIVATE void					connection_request() ;
 
 	FD_ZERO( &socket_mask ) ;
 	FD_SET( INT_REMOTE( ip ), &socket_mask ) ;
@@ -134,7 +132,8 @@ PRIVATE void si_mux()
 					msg( LOG_DEBUG, func, "Input available on local socket %d", 
 																			chp->ch_local_socket ) ;
 #endif
-				if ( handle_io( iter, chp, &socket_mask, tcp_local_to_remote ) == FAILED )
+				if ( handle_io( iter, chp,
+								&socket_mask, tcp_local_to_remote ) == FAILED )
 					return ;
 				if ( --n_ready == 0 )
 					break ;
@@ -175,12 +174,8 @@ PRIVATE status_e handle_io( iter, chp, maskp, iofunc )
 			if ( debug.on )
 				msg( LOG_DEBUG, func,
 					"Closing channel to %s,%d using sockets %d(l),%d(r)",
-						xntoa( chp->ch_from ),
-#ifdef INET6
-							ntohs( chp->ch_from.sin6_port ),
-#else
+						inet_ntoa( chp->ch_from.sin_addr ),
 							ntohs( chp->ch_from.sin_port ),
-#endif
 								chp->ch_local_socket, chp->ch_remote_socket ) ;
 
 			FD_CLR( chp->ch_local_socket, maskp ) ;
@@ -199,13 +194,7 @@ PRIVATE void connection_request( ip, chpp )
 	struct intercept	*ip ;
 	channel_s			**chpp ;
 {
-#ifdef INET6
-	struct sockaddr_in6	sin ;
-	unsigned short *port = &sin.sin6_port;
-#else
 	struct sockaddr_in	sin ;
-	unsigned short *port = &sin.sin_port;
-#endif
 	int						sin_len = sizeof( sin ) ;
 	channel_s				*chp ;
 	int						sd ;
@@ -221,7 +210,7 @@ PRIVATE void connection_request( ip, chpp )
 
 	if ( debug.on )
 		msg( LOG_DEBUG, func, "connection request from %s,%d",
-			xntoa( sin ), ntohs( *port ) ) ;
+			inet_ntoa( sin.sin_addr ), ntohs( sin.sin_port ) ) ;
 
 	chp = int_lookupconn( ip, &sin, &addr_checked ) ;
 	if ( chp == NULL )
@@ -273,7 +262,7 @@ PRIVATE void connection_request( ip, chpp )
 	else
 		msg( LOG_ERR, func,
 			"Received another connection request from %s,%d",
-				xntoa( sin ), ntohs( *port ) ) ;
+				inet_ntoa( sin.sin_addr ), ntohs( sin.sin_port ) ) ;
 }
 
 
