@@ -4,27 +4,23 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: util.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
+static char RCSid[] = "$Id: util.c,v 1.1 1996/01/24 19:29:19 chuck Exp $" ;
 
+#include <syslog.h>
 #include <sys/types.h>
 /*
  * The following ifdef is for TIOCNOTTY
  */
 #ifndef NO_TERMIOS
-#ifdef HAVE_SYS_TERMIOS_H
 #include <sys/termios.h>
-#endif
-#ifdef HAVE_TERMIOS_H
-#include <termios.h>
-#endif
 #else
 #include <sys/ioctl.h>
 #endif
 #include <fcntl.h>
 
 #include <memory.h>
-#include <syslog.h>
 #include <errno.h>
+#include <varargs.h>
 
 #include "pset.h"
 #include "misc.h"
@@ -160,7 +156,6 @@ status_e copy_pset( from, to, size )
  */
 void no_control_tty()
 {
-#ifndef HAVE_SETSID
    int fd ;
    char *func = "no_control_tty" ;
 
@@ -173,9 +168,6 @@ void no_control_tty()
       (void) close( fd ) ;
    }
    (void) setpgrp( getpid(), 0 ) ;
-#else
-	(void) setsid() ;
-#endif
 }
 
 
@@ -204,7 +196,11 @@ status_e write_buf( fd, buf, len )
 }
 
 
-void tabprint( int fd, int tab_level, char *fmt, ...)
+void tabprint( fd, tab_level, fmt, va_alist )
+   int fd ;
+   int tab_level ;
+   char *fmt ;
+   va_dcl
 {
    va_list ap ;
    int i ;
@@ -212,7 +208,7 @@ void tabprint( int fd, int tab_level, char *fmt, ...)
    for ( i = 0 ; i < tab_level ; i++ )
       Sputchar( fd, '\t' ) ;
 
-   va_start( ap, fmt ) ;
+   va_start( ap ) ;
    Sprintv( fd, fmt, ap ) ;
    va_end( ap ) ;
 }
